package org.expeditee.actions;

import org.expeditee.gui.Browser;
import org.expeditee.gui.DisplayIO;
import org.expeditee.gui.Frame;
import org.expeditee.gui.FrameIO;
import org.expeditee.gui.FrameMouseActions;
import org.expeditee.gui.FreeItems;
import org.expeditee.gui.MessageBay;
import org.expeditee.items.Text;
import org.expeditee.items.widgets.InteractiveWidget;
import org.expeditee.items.widgets.JfxBrowser;
import org.expeditee.settings.exploratorysearch.ExploratorySearchSettings;
import org.expeditee.settings.network.NetworkSettings;

/**
 * List of actions which Exploratory Search uses.
 * @author csl14
 */
public class ExploratorySearchActions {
	
	/**
	 * Adds a text item to the cursor which is linked to a new frame with the web browser active overlay and a JavaFX browser.
	 * @param text The text item attached to the cursor.
	 */
	public static void startBrowserSession(Text text) {
		try {
			if (!(text instanceof Text)) {
				MessageBay.errorMessage("Must be a text item.");
				return;
			}
			
			if(text.getLink() != null) {						// text item can't already have a link
				MessageBay.errorMessage("Text item already has link.");
				return;
			}
			
			String url = "";
			
			// If no text with url is passed to action create a new text item
			if(!FreeItems.textOnlyAttachedToCursor()) {
				url = ExploratorySearchSettings.HomePage.get();			// use home page specified by settings
				text = DisplayIO.getCurrentFrame().addText(FrameMouseActions.getX(), FrameMouseActions.getY(), 
						"Web Browser Session", null);
				text.setParent(DisplayIO.getCurrentFrame());
				FrameMouseActions.pickup(text);
			} else {
				url = text.getText();							// get url from text attached to cursor if possible
			}
			
			// Set text to session id. TODO: set session id.
			text.setText("Web Browser Session");
			
			// Create new frame
			Frame frame = FrameIO.CreateNewFrame(text);
			text.setLink("" + frame.getNumber());				// link this text item to new frame
			
			// Remove everything from new page
			frame.removeAllItems(frame.getItems());
			
			// Add web browser active overlay and @old
			frame.addText(1100, 50, "@ao: 2", null, "overlayset2");
			frame.addText(1100, 20, "@old", null);
			
			Text wt;
			
			// Extract marigns from settings
			int lm = ExploratorySearchSettings.BrowserLeftMargin.get();
			int rm = ExploratorySearchSettings.BrowserRightMargin.get();
			int tm = ExploratorySearchSettings.BrowserTopMargin.get();
			int bm = ExploratorySearchSettings.BrowserBottomMargin.get();
			
			// Start Browser in fullscreen or default, depending on settings
			if(ExploratorySearchSettings.BrowserFullScreen.get()) {
				wt = frame.addText(0 + lm, 70 + tm, "@iw: org.expeditee.items.widgets.JfxBrowser "+ (Browser._theBrowser.getWidth() - 
						JfxBrowser.HORZ_CROP - lm - rm) + " " + (Browser._theBrowser.getHeight() - JfxBrowser.VERT_CROP - 
						JfxBrowser.VERT_OFFSET - tm - bm) +	" : " + url, null);
			} else {
				wt = frame.addText(0 + lm, 70 + tm, "@iw: org.expeditee.items.widgets.JfxBrowser " + 
						(ExploratorySearchSettings.BrowserDefaultWidth.get() - lm - rm) + " " + 
						(ExploratorySearchSettings.BrowserDefaultHeight.get() - tm - bm) + " : " + url, null);
			}
			
			// Create widget via text annotation
			InteractiveWidget.createWidget(wt);
			
			FrameIO.SaveFrame(frame);							// save frame to disk
		} catch(Exception e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * Adds a text item to the cursor which is linked to a new frame with the mindmap active overlay.
	 */
	public static void startMindmapSession() {
		// Replace any text item on cursor with link to a new mindmap
		FreeItems.getInstance().clear();
		Text text = DisplayIO.getCurrentFrame().addText(FrameMouseActions.getX(), FrameMouseActions.getY(), "Mindmap Session", null);
		text.setParent(DisplayIO.getCurrentFrame());
		FrameMouseActions.pickup(text);
		Frame frame = FrameIO.CreateNewFrame(text);
		text.setLink("" + frame.getNumber());
		
		// Clear new frame and add active overlay and @old
		frame.removeAllItems(frame.getItems());
		frame.addText(1100, 50, "@ao: 2", null, "overlayset3");
		frame.addText(1100, 20, "@old", null);
		
		FrameIO.SaveFrame(frame);
	}
	
}
